require "omniauth-oauth2"

module OmniAuth
  module Strategies
    class SSL < OmniAuth::Strategies::OAuth2
      option :client_options, {
        site: "http://login.ssl.com",
        authorize_url: "https://login.ssl.com/oauth2/authorize",
        token_url: "https://login.ssl.com/oauth2/token"
      }

      uid do
        raw_info[0]["user"]["user_id"]
      end

      info do
        {
          user: {
            user_id: raw_info[0]["user"]["user_id"],
            user_email: raw_info[0]["user"]["user_email"],
            username: raw_info[0]["user"]["username"],
            ssl_account_id: raw_info[0]["user"]["ssl_account_id"],
          },
          client: {
            id: raw_info[0]["client"]["id"],
          }
        }
      end

      extra do
        { raw_info: raw_info }
      end

      def raw_info
        @raw_info ||= JWT.decode(access_token.token, nil, false, { algorithms: ['RS256']})
      end
    end
  end
end

OmniAuth.config.add_camelization 'ssl', 'SSL'
